@@ -4,6 +4,7 @@ import typer
 from .service import (
     handle_login,
     handle_logout,
+    handle_auth_status,
     handle_generate_cmd,
     handle_chat,
     handle_history_cmd,
@@ -46,25 +47,27 @@ def _version_callback(value: bool):
 
 @app.callback(invoke_without_command=True)
 def main(
+    ctx: typer.Context,
     version: bool = typer.Option(
         None,
         "--version",
         callback=_version_callback,
         is_eager=True,
         help="Show the version and exit.",
-    )
+    ),
 ):
-    """Root callback to handle global options like --version."""
-    # No action needed – commands are added below.
+    """Root callback to handle global options like --version.
+    If no sub‑command is provided, show a short hint directing the user to the help output.
+    """
+    if ctx.invoked_subcommand is None:
+        # No command was supplied – give a friendly hint.
+        typer.echo("Run 'aye --help' to see available commands.")
+    # No further action needed – commands are added below.
     return
 
 # Create subcommands
 auth_app = typer.Typer(help="Authentication commands")
-snap_app = typer.Typer(help="Snapshot management commands")
-
 app.add_typer(auth_app, name="auth")
-app.add_typer(snap_app, name="snap")
-
 # ----------------------------------------------------------------------
 # Authentication commands
 # ----------------------------------------------------------------------
@@ -75,38 +78,25 @@ def login():
     """
     handle_login()
 
-
 @auth_app.command()
 def logout():
     """
     Remove the stored aye credentials.
-    
+
     Examples: \n
     aye auth logout
     """
     handle_logout()
 
-# ----------------------------------------------------------------------
-# One‑shot generation
-# ----------------------------------------------------------------------
-@app.command()
-def generate(
-    prompt: str = typer.Argument(..., help="Prompt for the LLM"),
-    mode: str = typer.Option(
-        "replace",
-        "--mode",
-        "-m",
-        help="replace | append | insert (default: replace)",
-    ),
-):
+@auth_app.command()
+def status():
     """
-    Send a single prompt to the backend.
-    
+    Show authentication status and whether a token is saved.
+
     Examples: \n
-    aye generate "Create a function that reverses a string" \n
-    aye generate "Add type hints to this function" --mode append \n
+    aye auth status
     """
-    handle_generate_cmd(prompt, mode)
+    handle_auth_status()
 
 # ----------------------------------------------------------------------
 # Interactive REPL (chat) command
@@ -117,22 +107,25 @@ def chat(
         None, "--root", "-r", help="Root folder where source files are located."
     ),
     file_mask: str = typer.Option(
-        None, "--file-mask", "-m", help="File mask for source files to include into generation. Comma-separated masks are allowed."
+        None, "--include", "-i", help="Include patterns for source files to include into generation. Comma-separated globs are allowed."
     ),
 ):
     """
-    Start an interactive REPL. Use /exit or Ctrl‑D to leave.
+    Start an interactive REPL. Use exit or Ctrl‑D to leave.
     
     Examples: \n
     aye chat \n
     aye chat --root ./src \n
-    aye chat --file-mask "*.js" --root ./frontend \n
+    aye chat --include "*.js,*.html" --root ./frontend \n
     """
     handle_chat(root, file_mask)
 
 # ----------------------------------------------------------------------
 # Snapshot commands
 # ----------------------------------------------------------------------
+snap_app = typer.Typer(help="Snapshot management commands (EXPERIMENTAL)")
+app.add_typer(snap_app, name="snap")
+
 @snap_app.command("history")
 def history(
     file: Path = typer.Argument(None, help="File to list snapshots for")
@@ -146,11 +139,10 @@ def history(
     """
     handle_history_cmd(file)
 
-
 @snap_app.command("show")
 def show(
     file: Path = typer.Argument(..., help="File whose snapshot to show"),
-    ordinal: str = typer.Argument(..., help="Ordinal of the snapshot (e.g., 001)"),
+    ordinal: str = typer.Argument(..., help="Snapshot ID of the snapshot (e.g., 001)"),
 ):
     """
     Print the contents of a specific snapshot.
@@ -160,14 +152,13 @@ def show(
     """
     handle_snap_show_cmd(file, ordinal)
 
-
 @snap_app.command("restore")
 def restore(
-    ordinal: str = typer.Argument(None, help="Ordinal of the snapshot to restore (e.g., 001, default: latest)"),
+    ordinal: str = typer.Argument(None, help="Snapshot ID of the snapshot to restore (e.g., 001, default: latest)"),
     file_name: str = typer.Argument(None, help="Specific file to restore from the snapshot"),
 ):
     """
-    Replace all files with the latest snapshot or specified snapshot by ordinal.
+    Replace all files with the latest snapshot or specified snapshot by snapshot ID.
     If file_name is provided, only that file is restored.
     
     Examples:\n
@@ -194,7 +185,6 @@ def keep(
     """
     handle_prune_cmd(num)
 
-
 @snap_app.command()
 def cleanup(
     days: int = typer.Option(30, "--days", "-d", help="Delete snapshots older than N days (default: 30)"),
@@ -209,6 +199,27 @@ def cleanup(
     """
     handle_cleanup_cmd(days)
 
+# ----------------------------------------------------------------------
+# One‑shot generation
+# ----------------------------------------------------------------------
+#@app.command()
+def generate(
+    prompt: str = typer.Argument(..., help="Prompt for the LLM"),
+    mode: str = typer.Option(
+        "replace",
+        "--mode",
+        "-m",
+        help="replace | append | insert (default: replace)",
+    ),
+):
+    """
+    Send a single prompt to the backend.
+    
+    Examples: \n
+    aye generate "Create a function that reverses a string" \n
+    aye generate "Add type hints to this function" --mode append \n
+    """
+    handle_generate_cmd(prompt, mode)
 
 # ----------------------------------------------------------------------
 # Configuration management commands
@@ -220,7 +231,7 @@ def config(
     value: str = typer.Argument(None, help="Configuration value (for set action)"),
 ):
     """
-    Manage configuration values for file masks, root directories, and other settings.
+    Manage configuration values for file masks, root directories, and other settings. (EXPERIMENTAL)
     
     Actions: \n
     - list: Show all configuration values \n
